@@ -15,7 +15,6 @@ except ImportError:  # python 2
     from urlparse import urljoin
     from urlparse import urlparse
 
-from pkg_resources import parse_version
 from requests import exceptions as requests_exceptions
 from requests import Session
 from requests.adapters import HTTPAdapter
@@ -41,62 +40,7 @@ logger = getLogger(__name__)
 getLogger("qbittorrentapi").addHandler(NullHandler())
 
 
-class HelpersMixIn(object):
-    """
-    Miscellaneous helper functions.
-    """
-
-    @classmethod
-    def _list2string(cls, input_list=None, delimiter="|"):
-        """
-        Convert entries in a list to a concatenated string
-
-        :param input_list: list to convert
-        :param delimiter: delimiter for concatenation
-        :return: if input is a list, concatenated string...else whatever the input was
-        """
-        is_string = isinstance(input_list, six_string_types)
-        is_iterable = isinstance(input_list, Iterable)
-        if is_iterable and not is_string:
-            return delimiter.join(map(str, input_list))
-        return input_list
-
-    @classmethod
-    def _suppress_context(cls, exc):
-        """
-        This is used to mask an exception with another one.
-
-        For instance, below, the divide by zero error is masked by the CustomException.
-            try:
-                1/0
-            except ZeroDivisionError:
-                raise suppress_context(CustomException())
-
-        Note: In python 3, the last line would simply be raise CustomException() from None
-        :param exc: new Exception that will be raised
-        :return: Exception to be raised
-        """
-        exc.__cause__ = None
-        return exc
-
-    @classmethod
-    def _is_version_less_than(cls, ver1, ver2, lteq=True):
-        """
-        Determine if ver1 is equal to or later than ver2.
-
-        Note: changes need to be reflected in decorators._is_version_less_than as well
-
-        :param ver1: version to check
-        :param ver2: current version of application
-        :param lteq: True for Less Than or Equals; False for just Less Than
-        :return: True or False
-        """
-        if lteq:
-            return parse_version(ver1) <= parse_version(ver2)
-        return parse_version(ver1) < parse_version(ver2)
-
-
-class Request(HelpersMixIn):
+class Request(object):
     """
     Facilitates HTTP requests to qBittorrent's Web API.
     """
@@ -154,6 +98,7 @@ class Request(HelpersMixIn):
         FORCE_SCHEME_FROM_HOST=False,
         RAISE_UNIMPLEMENTEDERROR_FOR_UNIMPLEMENTED_API_ENDPOINTS=False,
         RAISE_NOTIMPLEMENTEDERROR_FOR_UNIMPLEMENTED_API_ENDPOINTS=False,
+        RAISE_ERROR_FOR_UNSUPPORTED_QBITTORRENT_VERSIONS=False,
         VERBOSE_RESPONSE_LOGGING=False,
         PRINT_STACK_FOR_EACH_REQUEST=False,
         SIMPLE_RESPONSES=False,
@@ -174,6 +119,9 @@ class Request(HelpersMixIn):
             RAISE_UNIMPLEMENTEDERROR_FOR_UNIMPLEMENTED_API_ENDPOINTS
             or RAISE_NOTIMPLEMENTEDERROR_FOR_UNIMPLEMENTED_API_ENDPOINTS
         )
+        self._RAISE_UNSUPPORTEDVERSIONERROR = bool(
+            RAISE_ERROR_FOR_UNSUPPORTED_QBITTORRENT_VERSIONS
+        )
         if bool(DISABLE_LOGGING_DEBUG_OUTPUT):
             for logger_ in ("qbittorrentapi", "requests", "urllib3"):
                 if getLogger(logger_).level < 20:
@@ -211,6 +159,21 @@ class Request(HelpersMixIn):
         # Mocking variables until better unit testing exists
         self._MOCK_WEB_API_VERSION = MOCK_WEB_API_VERSION
 
+    @classmethod
+    def _list2string(cls, input_list=None, delimiter="|"):
+        """
+        Convert entries in a list to a concatenated string
+
+        :param input_list: list to convert
+        :param delimiter: delimiter for concatenation
+        :return: if input is a list, concatenated string...else whatever the input was
+        """
+        is_string = isinstance(input_list, six_string_types)
+        is_iterable = isinstance(input_list, Iterable)
+        if is_iterable and not is_string:
+            return delimiter.join(map(str, input_list))
+        return input_list
+
     def _get(self, _name=APINames.EMPTY, _method="", **kwargs):
         return self._request_manager(
             http_method="get", api_namespace=_name, api_method=_method, **kwargs
